Documentation
¶
Overview ¶
Package conf provide functions for loading config from yaml file or env variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoadENV ¶
LoadENV fills config variable from envs based on supplied prefix NOTE: Slices in ENVs need value separation by comma: val1,val2,..
func ReadFlagsHelper ¶
func ReadFlagsHelper() (confFile, envPrefix string)
ReadFlagsHelper forces user to specify either yaml conf path or env prefix through flags and returns them
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.