Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OpenFileHelper ¶
OpenFileHelper tries to make or create file (including dirs) with proper flags for use in logger
func StaticHook ¶
StaticHook returns hook for logging static name, value pair to every probe (like hostname, PID, local IP and such..), basic types are cast to avoid reflection
func TimestampHook ¶
TimestampHook returns hook for logging UnixNano timestamp as float64
Types ¶
type Logger ¶
Logger represents wraper for logging mechanism
func New ¶
New creates logger if opening log file fails, logger will fallback to stderr you might want to use a log router like https://github.com/agnivade/funnel to handle app log output
Click to show internal directories.
Click to hide internal directories.